***********************************************************************
*                                                                     *
*                          REGIONAL ELECTIONS                         *
*                                                                     *
***********************************************************************

*******************************************************************************************************
* Notes:                                                                                              *
* (0) Regional Parties are defined as parties that compete in only one region per regional election   *
*      cycle defined by the index variable in the dataset.                                            *
* (1) For countries in which there is only 1 regional election (i.e., Northern Ireland pre-1990s),    *
*     the region party electoral figures are not calculated.                                          *
* (2) No countries have mixed electoral systems.                                                      *
* (3) All presidential elections that are concurrent with legislative elections are also              * 
*     concurrent with regional elections.                                                             *
*                                                                                                     *  
*******************************************************************************************************

************************************************************************************************
*                     Defintion of Variables                                                   *
************************************************************************************************
* felectNL = the first national elections were held in this year                               *
* felectRL = the first regional elections were held in this year                               *
* felectNATfirst = the first national elections occurred before the first regional elections   *
*   [All elections in a country (not only the first elections are coded 1)]                    *
* SIMfirstNATRL = the first national elections occurred at the same time as the first          *
*   regional elections. [Only the regional elections held in this year are coded 1             *
* SIM2firstNATRL= the first national elections occurred at the same time as the first          *
*   regional elections. [All elections in a country (not only the first elections are coded 1)]*
* prz = presidential system.                                                                   *
* przcon = presidential election held at the same time as regional election                    *
*   [All presidential elections in this case are held at the same time/year as national        *
*    legislative and all regional elections]                                                   *                  *
* prznoncon = presidential election not held at the same time/year as regional election        *
* parlcon = election of prime minister held at the same time/year as regional election.        *
*   [All pm elections are held at the same time as national legislative and all regional       *
     elections]                                                                                *
* parlnoncon = election of prime minister not held at the same time as regional election.      *
************************************************************************************************

**((CHAPTER MODELS))**

reg furpVOTE majplr przcon parlnoncon prznoncon noelections Xlaw sixties seventies eighties nineties, robust
 outreg majplr przcon parlnoncon prznoncon noelections Xlaw using Book_QAIII, replace se 3aster coefastr bdec(2) rdec(3)title (Regional Elections) nonotes addnote(Decade-fixed effects not shown. Standard errors in parentheses.  *p=0.10, **p=0.05, ***p=0.01.)
*reg furpVOTE majplr prz noelections Xlaw sixties seventies eighties nineties, robust
reg furpVOTE majplr concurrentALL noelections Xlaw sixties seventies eighties nineties, robust
 outreg majplr concurrentALL noelections Xlaw using Book_QAIII, append replace se 3aster coefastr bdec(2) rdec(3)title (Regional Elections) nonotes addnote(Decade-fixed effects not shown. Standard errors in parentheses.  *p=0.10, **p=0.05, ***p=0.01.)
reg furpVOTE majplr felectNL przcon parlnoncon prznoncon noelections Xlaw sixties seventies eighties nineties, robust 
 outreg majplr felectNL przcon parlnoncon prznoncon noelections Xlaw  using Book_QAIII, append replace se 3aster coefastr bdec(2) rdec(3)title (Regional Elections) nonotes addnote(Decade-fixed effects not shown. Standard errors in parentheses.  *p=0.10, **p=0.05, ***p=0.01.)
reg furpVOTE majplr felectNL felectRL przcon parlnoncon prznoncon noelections Xlaw sixties seventies eighties nineties, robust 
 outreg majplr felectNL felectRL przcon parlnoncon prznoncon noelections Xlaw using Book_QAIII, append replace se 3aster coefastr bdec(2) rdec(3)title (Regional Elections) nonotes addnote(Decade-fixed effects not shown. Standard errors in parentheses.  *p=0.10, **p=0.05, ***p=0.01.)
 *reg furpVOTE majplr age przcon parlnoncon prznoncon noelections Xlaw sixties seventies eighties nineties, robust
 *reg furpVOTE majplr felectRL przcon parlnoncon prznoncon noelections Xlaw sixties seventies eighties nineties, robust 
reg furpVOTE majplr SIMfirstNATRL przcon parlnoncon prznoncon noelections Xlaw sixties seventies eighties nineties, robust  
 outreg majplr felectNATfirst SIM2firstNATRL przcon parlnoncon prznoncon noelections Xlaw using Book_QAIII, append replace se 3aster coefastr bdec(2) rdec(3)title (Regional Elections) nonotes addnote(Decade-fixed effects not shown. Standard errors in parentheses.  *p=0.10, **p=0.05, ***p=0.01.)
 
*Note: There is insufficient data to test the interaction between felectRL and sim.*

**((APPENDIX MODELS))**
*CLUSTERED SE BY COUNTRY** 

reg furpVOTE majplr przcon parlnoncon prznoncon noelections Xlaw sixties seventies eighties nineties, cluster(cnty)
 outreg using Book_Appendix_QAIII, replace se 3aster coefastr bdec(2)  rdec(3)title (Regional Elections -- SEs Clustered by Country) nonotes addnote(Decade-fixed effects not shown. Standard errors in parentheses.  *p=0.10, **p=0.05, ***p=0.01.)
reg furpVOTE majplr concurrentALL noelections Xlaw sixties seventies eighties nineties, cluster(cnty)
 outreg using Book_Appendix_QAIII, append replace se 3aster coefastr bdec(2)  rdec(3)title (Regional Elections) nonotes addnote(Decade-fixed effects not shown. Standard errors in parentheses.  *p=0.10, **p=0.05, ***p=0.01.)
reg furpVOTE majplr felectNL przcon parlnoncon prznoncon noelections Xlaw sixties seventies eighties nineties, cluster(cnty)
 outreg using Book_Appendix_QAIII, append replace se 3aster coefastr bdec(2)  rdec(3)title (Regional Elections) nonotes addnote(Decade-fixed effects not shown. Standard errors in parentheses.  *p=0.10, **p=0.05, ***p=0.01.)
reg furpVOTE majplr felectNL felectRL przcon parlnoncon prznoncon noelections Xlaw sixties seventies eighties nineties, cluster(cnty)
 outreg using Book_Appendix_QAIII, append replace se 3aster coefastr bdec(2)  rdec(3)title (Regional Elections) nonotes addnote(Decade-fixed effects not shown. Standard errors in parentheses.  *p=0.10, **p=0.05, ***p=0.01.)
 *reg furpVOTE majplr felectRL przcon parlnoncon prznoncon noelections Xlaw sixties seventies eighties nineties, cluster(cnty) 
reg furpVOTE majplr SIMfirstNATRL przcon parlnoncon prznoncon noelections Xlaw sixties seventies eighties nineties, cluster(cnty) 
 outreg using Book_Appendix_QAIII, append replace se 3aster coefastr bdec(2)  rdec(3)title (Regional Elections) nonotes addnote(Decade-fixed effects not shown. Standard errors in parentheses.  *p=0.10, **p=0.05, ***p=0.01.)

*CLUSTERED SE BY ADMINISTRATIVE DIVISION** 
reg furpVOTE majplr przcon parlnoncon prznoncon noelections Xlaw sixties seventies eighties nineties, cluster(admdivision)
 outreg using Book_Appendix_QAIIIb, replace se 3aster coefastr bdec(2)  rdec(3)title (Regional Elections -- SEs Clustered by Administrative Division) nonotes addnote(Decade-fixed effects not shown. Standard errors in parentheses.  *p=0.10, **p=0.05, ***p=0.01.)
reg furpVOTE majplr concurrentALL noelections Xlaw sixties seventies eighties nineties, cluster(admdivision)
 outreg using Book_Appendix_QAIIIb, append replace se 3aster coefastr bdec(2)  rdec(3)title (Regional Elections) nonotes addnote(Decade-fixed effects not shown. Standard errors in parentheses.  *p=0.10, **p=0.05, ***p=0.01.)
reg furpVOTE majplr felectNL przcon parlnoncon prznoncon noelections Xlaw sixties seventies eighties nineties, cluster(admdivision)
 outreg using Book_Appendix_QAIIIb, append replace se 3aster coefastr bdec(2)  rdec(3)title (Regional Elections) nonotes addnote(Decade-fixed effects not shown. Standard errors in parentheses.  *p=0.10, **p=0.05, ***p=0.01.)
reg furpVOTE majplr felectNL felectRL przcon parlnoncon prznoncon noelections Xlaw sixties seventies eighties nineties, cluster(admdivision)
 outreg using Book_Appendix_QAIIIb, append replace se 3aster coefastr bdec(2)  rdec(3)title (Regional Elections) nonotes addnote(Decade-fixed effects not shown. Standard errors in parentheses.  *p=0.10, **p=0.05, ***p=0.01.)
 *reg furpVOTE majplr felectRL przcon parlnoncon prznoncon noelections Xlaw sixties seventies eighties nineties, cluster(admdivision)
reg furpVOTE majplr SIMfirstNATRL przcon parlnoncon prznoncon noelections Xlaw sixties seventies eighties nineties, cluster(admdivision) 
 outreg using Book_Appendix_QAIIIb, append replace se 3aster coefastr bdec(2)  rdec(3)title (Regional Elections) nonotes addnote(Decade-fixed effects not shown. Standard errors in parentheses.  *p=0.10, **p=0.05, ***p=0.01.)

