* ###################################################*
*  QUANTIATIVE ANALYSIS I, PEACE BY DESIGN (BRANCATI)*
*####################################################*

**************************************************************************************************
* Notes:                                                                                         *
*(1) All countries are not included every year between 1985-2000 due to lack of election data    * 
*    for these years.                                                                            *     
*(2) The data has been updated from Brancati (2006) to reflect new and revised data available    *
*    from the World Bank and IMF, as well as new election data.                                  *                                                *                   												 *
**************************************************************************************************


*****((((CHANGE ALL AGE VARIABLES TO FIRST ELECTION VARIABLES)))))************

********************************************************************************
*			     DEFINITION OF VARIABLES                                 *  
********************************************************************************
*  rebelmax = maximum of rebellion among territorially concentrated groups.    *
*  comcomax = maximum of conflict among territorially concentrated groups.     *
*  rebelmean = mean of rebellion among territorially concentrated groups.      *
*  comcomean = mean of conflict among territorially concentrated groups.       *
*  dcen = dichotomous measure of decentralization				      			*
*  dcenIndex = index of decentralization			                         	*
*  furpVOTE = regional party vote (% of total vote)                            *
*  furpSEAT = regional party vote (% of total seats)                           *
*  furpNUMBER = regional parties (% of all parties)			             		*
*  EXPshare05 = subnational expenditure (% of total expenditure)               *
*  EXPgdp05 = subnational expenditure (% of gdp)           			       *
*  REVgdp05 = subnational expenditure (% of gdp)                               *
*  fh = freedom house democracy index (1=free; 7=not free)			       *
*  mixed = mixed electoral system							       *
*  majplr = majority and plurality systems				             *
*  age = age of democracy				                               *
*  elect = election year                                                       *
*  felect = election year of first democratic elections      	             *
*  felect2 = years in which first democratically-elected legislature in office *
*  lnGDP05 = log of GDP05 (current US dollars)					       *
*  lnGDPcap05 = log of GDP05 per capita (constant US dollars)    		       *
*  prz = presidentialism								       *	
*  przcon = concurrent presidential and legislative elections		       *
*  przncon = nonconcurrent presidential and legislative elections		       *
*  elf = ethnolinguistic fractionalization (elf) index.	 		       *
*  sqelf = square of elf index			       				 *
*  noncontig = country whose territory is noncontiguous			       *
*  UKcolony = former colony of the United Kingdom				       *
********************************************************************************

*##############################################################################################*
*                     #################################################                        *
*                     #  DEPENDENT VARIABLE  - ANTI-REGIME REBELLION  #                        *
*                     #################################################                        *
*##############################################################################################*

use "D:\Book Analysis I\Brancati_PBDQA1short.dta", clear

***********************************************************************************************************
* REBELLION - DECENTRALIZATION PLUS ALTERNATIVE EXPLANATION MODELS                                        *
***********************************************************************************************************

****************
*CHAPTER MODELS*
****************

ologit rebelmax dcen fh mixed majplr age prz elf lnGDP05  y1-y16, robust
 outreg dcen fh mixed majplr age prz elf lnGDP05 using Book_Rebellion1, replace se 3aster coefastr bdec(2) rdec(3) addstat(Log Pseudolikelihood,  e(ll)) adec(3)
prvalue, x(dcen=0 fh=1 mixed=0 majplr=0 prz=1) rest(mean) 
prvalue, x(dcen=1 fh=1 mixed=0 majplr=0 prz=1) rest(mean) 

*****************
*APPENDIX MODELS*
*****************

*SQUARED ELF TERM*
ologit rebelmax dcen fh mixed majplr age prz elf lnGDP05 sqelf y1-y16, robust
 outreg dcen fh mixed majplr age prz elf lnGDP05 sqelf using Book_Appendix_Rebellion1, replace se 3aster coefastr bdec(2) rdec(3) addstat(Log Pseudolikelihood,  e(ll)) adec(3) title(Anti-regime Rebellion: Alternative ELF and GDP Models (Base Models))

*BASE MODEL WITH SUBSTITUTIONS - PER CAPITA GDP INSTEAD OF TOTAL GDP*

ologit rebelmax dcen fh mixed majplr age prz elf lnGDP05 lnGDPcap05 elf y1-y16, robust
 outreg dcen fh mixed majplr age prz elf lnGDP05 lnGDPcap05 elf using Book_Appendix_Rebellion1, append replace se 3aster coefastr bdec(2) rdec(3) addstat(Log Pseudolikelihood,  e(ll)) adec (3) 

ologit rebelmax dcen fh mixed majplr age prz lnGDPcap05 elf y1-y16, robust
 outreg dcen fh mixed majplr age prz lnGDPcap05 elf using Book_Appendix_Rebellion1, append replace se 3aster coefastr bdec(2) rdec(3) addstat(Log Pseudolikelihood,  e(ll)) adec (3)

*BASE MODEL WITH SUBSTITUTIONS - ALTERNATIVE MEASURES OF ELECTIONS/ELECTORAL SYSTEM TYPE*

ologit rebelmax dcen fh avdm age prz elf lnGDP05 y1-y16, robust
 outreg dcen fh avdm age prz elf lnGDP05  using Book_Appendix_Rebellion1a, replace se 3aster coefastr bdec(2) rdec(3) addstat(Log Pseudolikelihood,  e(ll)) adec(3) title (Anti-regime Rebellion: Alternative Measures of Elections (Base Models))

ologit rebelmax dcen fh mixed majplr felect prz elf lnGDP05  y1-y16, robust
 outreg dcen fh mixed majplr felect prz elf lnGDP05 using Book_Appendix_Rebellion1a, append replace se 3aster coefastr bdec(2) rdec(3) addstat(Log Pseudolikelihood,  e(ll)) adec(3)

ologit rebelmax dcen fh mixed majplr felect2 prz elf lnGDP05  y1-y16, robust
 outreg dcen fh mixed majplr felect2 prz elf lnGDP05 using Book_Appendix_Rebellion1a, replace append se 3aster coefastr bdec(2) rdec(3) addstat(Log Pseudolikelihood,  e(ll)) adec(3)


*********************************************************************************************************
* REBELLION - DECENTRALIZATION AND REGIONAL PARTY VOTE MODELS                                           * 
*********************************************************************************************************

****************
*CHAPTER MODELS*
****************

ologit rebelmax dcen furpNUMBER fh mixed majplr age prz elf lnGDP05 y1-y16, robust
  outreg dcen furpNUMBER fh mixed majplr age prz elf lnGDP05 using  Book_Rebellion1, append replace se 3aster coefastr bdec(2) rdec(3) addstat(Log Pseudolikelihood,  e(ll)) adec(3)
prvalue, x(dcen=1 furpNUMBER=28 fh=1  mixed=0 majplr=0 prz=1) rest(mean) 
prvalue, x(dcen=1 furpNUMBER=38 fh=1  mixed=0 majplr=0 prz=1) rest(mean) 

ologit rebelmax dcen furpVOTE fh mixed majplr age prz elf lnGDP05 y1-y16, robust
  outreg dcen furpVOTE fh mixed majplr age prz elf lnGDP05 using Book_Rebellion1, append replace se 3aster coefastr bdec(2) rdec(3) addstat(Log Pseudolikelihood,  e(ll)) adec(3)
prvalue, x(dcen=1 furpVOTE=5 fh=1  mixed=0 majplr=0 prz=1) rest(mean) 
prvalue, x(dcen=1 furpVOTE=15 fh=1  mixed=0 majplr=0 prz=1) rest(mean) 

ologit rebelmax dcen furpSEAT fh mixed majplr age prz elf lnGDP05 y1-y16, robust
  outreg dcen furpSEAT fh mixed majplr age prz elf lnGDP05 using Book_Rebellion1, append replace se 3aster coefastr bdec(2) rdec(3) addstat(Log Pseudolikelihood,  e(ll)) adec(3)
prvalue, x(dcen=1 furpSEAT=5 fh=1  mixed=0 majplr=0 prz=1) rest(mean) 
prvalue, x(dcen=1 furpSEAT=15 fh=1  mixed=0 majplr=0 prz=1) rest(mean) 

*****************
*APPENDIX MODELS*
*****************

*ALTERNATIVE MEASURES OF REGIONAL PARTIES - DENATIONALIZATION*
ologit rebelmax dcen denat fh mixed majplr age prz elf lnGDP05 y1-y16, robust
 outreg dcen denat fh mixed majplr age prz elf lnGDP05 using Book_Appendix_Rebellion1b, replace se 3aster coefastr bdec(2) rdec(3) addstat(Log Pseudolikelihood,  e(ll)) adec(3) title (Anti-regime Rebellion: Alternative Measures/Models of Regional Parties (Base Models)) 

*REBELLION TABLE MODELS OF NUMBER AND VOTES RESTRICTED TO SEAT POPULATION* 
ologit rebelmax dcen furpNUMBER fh mixed majplr age prz elf lnGDP05 y1-y16 if furpSEAT != ., robust
 outreg dcen furpNUMBER fh mixed majplr age prz elf lnGDP05 using Book_Appendix_Rebellion1b, append replace se 3aster coefastr bdec(2) rdec(3) addstat(Log Pseudolikelihood,  e(ll)) adec(3)

ologit rebelmax dcen furpVOTE fh mixed majplr age prz elf lnGDP05 y1-y16 if furpSEAT != ., robust
 outreg dcen furpVOTE fh mixed majplr age prz elf lnGDP05 using Book_Appendix_Rebellion1b, append replace se 3aster coefastr bdec(2) rdec(3) addstat(Log Pseudolikelihood,  e(ll)) adec(3)


*REBELLION TABLE MODELS WITHOUT ELF*

ologit rebelmax dcen furpVOTE fh mixed majplr age prz lnGDP05  y1-y16, robust
  outreg dcen furpVOTE fh mixed majplr age prz elf lnGDP05  using Book_Appendix_Rebellion1d, replace se 3aster coefastr bdec(2) rdec(3) addstat(Log Pseudolikelihood,  e(ll)) adec(3) title (Anti-regime Rebellion: Regional Party Vote Models with ELF)
 
ologit rebelmax dcen furpNUMBER fh mixed majplr age prz lnGDP05  y1-y16, robust
  outreg dcen furpNUMBER fh mixed majplr age prz elf lnGDP05 using Book_Appendix_Rebellion1d, append replace se 3aster coefastr bdec(2) rdec(3) addstat(Log Pseudolikelihood,  e(ll)) adec(3)

ologit rebelmax dcen furpSEAT fh mixed majplr age prz lnGDP05  y1-y16, robust
  outreg dcen furpSEAT fh mixed majplr age prz elf lnGDP05 using Book_Appendix_Rebellion1d, append replace se 3aster coefastr bdec(2) rdec(3) addstat(Log Pseudolikelihood,  e(ll)) adec(3)

*GEOGRAPHIC REGION MODELS*
clear 
use "D:\Book Analysis I\Brancati_PBDQA1long.gregions.dta"
ologit rebelmax dcen gfurp fh mixed majplr age prz elf lnGDP05  y1-y16, robust
  outreg dcen gfurp fh mixed majplr age prz elf lnGDP05 using Book_Appendix_Conflict1e, replace se 3aster coefastr bdec(2) rdec(3) addstat(Log Pseudolikelihood,  e(ll)) adec(3) title (Conflict: Regional Party Vote Models with ELF)
ologit rebelmax dcen gfurpVOTE fh mixed majplr age prz elf lnGDP05  y1-y16, robust
  outreg dcen gfurpVOTE fh mixed majplr age prz elf lnGDP05 using Book_Appendix_Conflict1e, replace se 3aster coefastr bdec(2) rdec(3) addstat(Log Pseudolikelihood,  e(ll)) adec(3) title (Conflict: Regional Party Vote Models with ELF)
ologit rebelmax dcen gfurpSEAT fh mixed majplr age prz elf lnGDP05  y1-y16, robust
  outreg dcen gfurpSEAT fh mixed majplr age prz elf lnGDP05 using Book_Appendix_Conflict1e, replace se 3aster coefastr bdec(2) rdec(3) addstat(Log Pseudolikelihood,  e(ll)) adec(3) title (Conflict: Regional Party Vote Models with ELF)


***************************************************************************************************************
* ALTERNATIVE MEASURES OF DECENTRALIZATION                                                                    *
***************************************************************************************************************

******************
* Chapter Models *
******************
ologit rebelmax dcenIndex furpVOTE fh mixed majplr age prz elf lnGDP05 y1-y16, robust
  outreg dcenIndex furpVOTE fh mixed majplr age prz elf lnGDP05 using Book_Rebellion2, replace se 3aster coefastr bdec(2) rdec(3) addstat(Log Pseudolikelihood,  e(ll)) adec(3)
*result the same without the elf index*
*ologit rebelmax dcenIndex furpVOTE fh mixed majplr age prz lnGDP05 y1-y16, robust
prvalue, x(dcenIndex=0 fh=1  mixed=0 majplr=0 prz=1) rest(mean)
prvalue, x(dcenIndex=3 fh=1  mixed=0 majplr=0 prz=1) rest(mean) 
prvalue, x(dcenIndex=5  fh=1  mixed=0 majplr=0 prz=1) rest(mean) 

ologit rebelmax dcen EXPshare05 furpVOTE fh mixed majplr age prz elf lnGDP05 y1-y16 if REVgdp05 !=., robust
   outreg dcen EXPshare05 furpVOTE fh mixed majplr age prz elf lnGDP05 using Book_Rebellion2, append replace se 3aster coefastr bdec(2) rdec(3) addstat(Log Pseudolikelihood,  e(ll)) adec(3)
*result the same without the elf index*
*ologit rebelmax dcen EXPshare05 furpVOTE fh mixed majplr age prz lnGDP05 y1-y16 if REVgdp05 !=., robust

ologit rebelmax dcen REVgdp05 furpVOTE fh mixed majplr age prz elf lnGDP05 y1-y16 if EXPshare05 !=., robust
 outreg dcen REVgdp05 furpVOTE fh mixed majplr age prz elf lnGDP05 using Book_Rebellion2, replace append se 3aster coefastr bdec(2) rdec(3) addstat(Log Pseudolikelihood,  e(ll)) adec(3)
*result the same without the elf index*
*ologit rebelmax dcen REVgdp05 furpVOTE fh mixed majplr age prz lnGDP05 y1-y16 if EXPshare05 !=., robust

*******************
* Appendix Models *
*******************

*ADDITIONAL FISCAL DECENTRALIZATION MODELS*

*ologit rebelmax dcen EXPgdp05 furpVOTE fh mixed majplr age prz elf lnGDP05 y1-y16 if REVgdp05 !=. & EXPshare05 !=., robust 
* Model does not converge.*significant if I drop the elf index.  

ologit rebelmax EXPshare05 furpVOTE fh mixed majplr age prz elf lnGDP05 y1-y16 if REVgdp05 !=., robust
   outreg EXPshare05 furpVOTE fh mixed majplr age prz elf lnGDP05 using Book_Appendix_Rebellion2b, replace se 3aster coefastr bdec(2) rdec(3) addstat(Log Pseudolikelihood,  e(ll)) adec(3) title (Anti-Regime Rebellion: Additional Fiscal Decentralization Models without Controls for Political Decentralization or Restricted to these Systems) 

ologit rebelmax REVgdp05 furpVOTE fh mixed majplr age prz elf lnGDP05 y1-y16 if EXPshare05 !=., robust
   outreg REVgdp05 furpVOTE fh mixed majplr age prz elf lnGDP05 using Book_Appendix_Rebellion2b, append replace se 3aster coefastr bdec(2) rdec(3) addstat(Log Pseudolikelihood,  e(ll)) adec(3)

ologit rebelmax EXPshare05 furpVOTE fh mixed majplr age prz elf lnGDP05 y1-y16 if REVgdp05 !=. & dcen == 1, robust
   outreg EXPshare05 furpVOTE fh mixed majplr age prz elf lnGDP05 using Book_Appendix_Rebellion2b, append replace se 3aster coefastr bdec(2) rdec(3) addstat(Log Pseudolikelihood,  e(ll)) adec(3)
*result the same without the elf index*

ologit rebelmax REVgdp05 furpVOTE fh mixed majplr age prz elf lnGDP05 y1-y16 if EXPshare05 !=. & dcen == 1, robust
   outreg REVgdp05 furpVOTE fh mixed majplr age prz elf lnGDP05 using Book_Appendix_Rebellion2b, append replace se 3aster coefastr bdec(2) rdec(3) addstat(Log Pseudolikelihood,  e(ll)) adec(3)
*result the same without the elf index*

*ADDITIONAL FISCAL DECENTRALIZATION MODELS: VARIATION ON REGIONAL PARTY VOTE*
ologit rebelmax dcen EXPshare05 furpNUMBER fh mixed majplr age prz elf lnGDP05 y1-y16, robust
   outreg dcen EXPshare05 furpNUMBER fh mixed majplr age prz elf lnGDP05 using Book_Appendix_Rebellion2b2, replace se 3aster coefastr bdec(2) rdec(3) addstat(Log Pseudolikelihood,  e(ll)) adec(3) title (Anti-Regime Rebellion: Additional Fiscal Decentralization Models with Variations on Regional Party Strength) 

ologit rebelmax dcen EXPshare05 furpSEAT fh mixed majplr age prz elf lnGDP05 y1-y16, robust
   outreg dcen EXPshare05 furpSEAT fh mixed majplr age prz elf lnGDP05 using Book_Appendix_Rebellion2b2, append replace se 3aster coefastr bdec(2) rdec(3) addstat(Log Pseudolikelihood,  e(ll)) adec(3)
*result the same without the elf index*

ologit rebelmax dcen REVgdp05 furpNUMBER fh mixed majplr age prz elf lnGDP05 y1-y16, robust
 outreg dcen REVgdp05 furpNUMBER fh mixed majplr age prz elf lnGDP05 using Book_Appendix_Rebellion2b2, append replace se 3aster coefastr bdec(2) rdec(3) addstat(Log Pseudolikelihood,  e(ll)) adec(3)

ologit rebelmax dcen REVgdp05 furpSEAT fh mixed majplr age prz elf lnGDP05 y1-y16, robust
 outreg dcen REVgdp05 furpSEAT fh mixed majplr age prz elf lnGDP05  using Book_Appendix_Rebellion2b2, append replace se 3aster coefastr bdec(2) rdec(3) addstat(Log Pseudolikelihood,  e(ll)) adec(3)


*REBELLION TABLE MODELS RESTRICTED TO SAME POPULATION AS FISCAL DECENTRALIZATION MODEL*

ologit rebelmax dcen fh mixed majplr age prz elf lnGDP05 y1-y16 if EXPshare05 != . & REVgdp05 != ., robust
   outreg dcen fh mixed majplr age prz elf lnGDP05 using Book_Appendix_Rebellion2c, replace se 3aster coefastr bdec(2) rdec(3) addstat(Log Pseudolikelihood,  e(ll)) adec(3) title (Rebellion Models Restricted to the Same Population as the Fiscal Decentralization Models)
*result the same without the elf index*

ologit rebelmax dcen furpNUMBER fh mixed majplr age prz elf lnGDP05 y1-y16 if EXPshare05 != . & REVgdp05 != ., robust
   outreg dcen furpNUMBER fh mixed majplr age prz elf lnGDP05  using Book_Appendix_Rebellion2c, append replace se 3aster coefastr bdec(2) rdec(3) addstat(Log Pseudolikelihood,  e(ll)) adec(3)

ologit rebelmax dcen furpVOTE fh mixed majplr age prz elf lnGDP05 y1-y16 if EXPshare05 != . & REVgdp05 != ., robust
   outreg dcen furpVOTE fh mixed majplr age prz elf lnGDP05 using Book_Appendix_Rebellion2c, append replace se 3aster coefastr bdec(2) rdec(3) addstat(Log Pseudolikelihood,  e(ll)) adec(3)
*result not the same for furpVOTE without the elf index*

ologit rebelmax dcen furpSEAT fh mixed majplr age prz elf lnGDP05 y1-y16 if EXPshare05 != . & REVgdp05 != ., robust
   outreg dcen furpSEAT fh mixed majplr age prz elf lnGDP05  using Book_Appendix_Rebellion2c, append replace se 3aster coefastr bdec(2) rdec(3) addstat(Log Pseudolikelihood,  e(ll)) adec(3)
*result not the same for furpSEAT without the elf index*

ologit rebelmax dcenIndex furpVOTE fh mixed majplr age prz elf lnGDP05 y1-y16 if EXPshare05 != . & REVgdp05 != . , robust
   outreg dcenIndex furpVOTE fh mixed majplr age prz elf lnGDP05 using Book_Appendix_Rebellion2c, append replace se 3aster coefastr bdec(2) rdec(3) addstat(Log Pseudolikelihood,  e(ll)) adec(3)
*result the same without the elf index*


*************************************************************************************************************
* REBELLION - DECENTRALIZATION INTERACTION MODELS                                                           *
*************************************************************************************************************

****************
*CHAPTER MODELS*
****************

gen dcenNUMBER = dcen*furpNUMBER 
ologit rebelmax dcen furpNUMBER dcenNUMBER fh mixed majplr age prz elf lnGDP05 y1-y16, robust
outreg dcen furpNUMBER dcenNUMBER fh mixed majplr age prz elf lnGDP05  using Book_Rebellion3, replace se 3aster coefastr bdec(2) rdec(3) addstat(Log Pseudolikelihood,  e(ll)) adec(3)
test dcen furpNUMBER dcenNUMBER
*ologit rebelmax dcen furpNUMBER dcenNUMBER fh mixed majplr age prz elf lnGDP05 y1-y16 if furpSEAT !=., robust 

gen dcenVOTE = dcen*furpVOTE 
ologit rebelmax dcen furpVOTE dcenVOTE fh mixed majplr age prz elf lnGDP05 y1-y16, robust
outreg dcen furpVOTE dcenVOTE fh mixed majplr age prz elf lnGDP05  using Book_Rebellion3, append replace se 3aster coefastr bdec(2) rdec(3) addstat(Log Pseudolikelihood,  e(ll)) adec(3)
test dcen furpVOTE dcenVOTE
*result the same without the elf index*
*ologit rebelmax dcen furpVOTE dcenVOTE fh mixed majplr age prz lnGDP05 y1-y16, robust
*ologit rebelmax dcen furpVOTE dcenVOTE fh mixed majplr age prz elf lnGDP05 y1-y16 if  furpSEAT !=., robust

gen dcenSEAT = dcen*furpSEAT 
ologit rebelmax dcen furpSEAT dcenSEAT fh mixed majplr age prz elf lnGDP05 y1-y16, robust
outreg dcen furpSEAT dcenSEAT fh mixed majplr age prz elf lnGDP05  using Book_Rebellion3, append replace se 3aster coefastr bdec(2) rdec(3) addstat(Log Pseudolikelihood,  e(ll)) adec(3)
test dcen furpSEAT dcenSEAT

******************
* APPENDIX MODELS *
******************

*INTERACTION MODELS WITH ALTERNATIVE MEASURES OF DECENTRALIZATION/REGIONAL PARTIES*

gen furpvoteEXPshare05 = furpVOTE*EXPshare05
ologit rebelmax dcen furpVOTE furpvoteEXPshare05 EXPshare05 fh mixed majplr age prz elf lnGDP05 y1-y16, robust
outreg dcen furpVOTE furpvoteEXPshare05 EXPshare05 fh mixed majplr age prz elf lnGDP05 using Book_Appendix_Rebellion3a, replace se 3aster coefastr bdec(2) rdec(3) addstat(Log Pseudolikelihood,  e(ll)) adec(3) title(Alternative Interaction Models)
test dcen EXPshare05 furpvoteEXPshare05

gen dcenIVote = dcenIndex*furpVOTE 
ologit rebelmax dcenIndex furpVOTE dcenIVote fh mixed majplr age prz elf lnGDP05 y1-y16, robust
outreg dcenIndex furpVOTE dcenIVote fh mixed majplr age prz elf lnGDP05  using Book_Appendix_Rebellion3a, append replace se 3aster coefastr bdec(2) rdec(3) addstat(Log Pseudolikelihood,  e(ll)) adec(3)
test dcenIndex furpVOTE dcenIVote
prvalue, x(dcenIndex=1 furpVOTE = 5 dcenIVote=5 fh=1 mixed=0 majplr=0 prz=1) rest(mean) save
prvalue, x(dcenIndex=1 furpVOTE = 15 dcenIVote=5 fh=1 mixed=0 majplr=0 prz=1) rest(mean) diff
prvalue, x(dcenIndex=4 furpVOTE = 5 dcenIVote=5 fh=1 mixed=0 majplr=0 prz=1) rest(mean)
prvalue, x(dcenIndex=4 furpVOTE = 15 dcenIVote=5 fh=1 mixed=0 majplr=0 prz=1) rest(mean)

gen dcenISeat = dcenIndex*furpSEAT 
ologit rebelmax dcenIndex furpSEAT dcenISeat fh mixed majplr age prz elf lnGDP05 y1-y16, robust
test dcenIndex furpSEAT dcenISeat
prvalue, x(dcenIndex=1 furpSEAT = 5 dcenISeat=5 fh=1 mixed=0 majplr=0 prz=1) rest(mean) save
prvalue, x(dcenIndex=1 furpSEAT = 15 dcenISeat=5 fh=1 mixed=0 majplr=0 prz=1) rest(mean) diff
prvalue, x(dcenIndex=4 furpSEAT = 5 dcenISeat=5 fh=1 mixed=0 majplr=0 prz=1) rest(mean)
prvalue, x(dcenIndex=4 furpSEAT = 15 dcenISeat=5 fh=1 mixed=0 majplr=0 prz=1) rest(mean)

gen dcenDENAT = dcen*denat
ologit rebelmax dcen dcenDENAT denat fh mixed majplr age prz elf lnGDP05 y1-y16, robust
outreg dcen dcenDENAT denat fh mixed majplr age prz elf lnGDP05  using Book_Appendix_Rebellion3a, append replace se 3aster coefastr bdec(2) rdec(3) addstat(Log Pseudolikelihood,  e(ll)) adec(3)
test dcen denat dcenDENAT


 
*##############################################################################################*
*                     #################################################                        *
*                     # DEPENDENT VARIABLE  - INTER-COMMUNAL CONFLICT #                        *
*                     #################################################                        *
*##############################################################################################*

***********************************************************************************************************
* CONFLICT - DECENTRALIZATION PLUS ALTERNATIVE EXPLANATION MODELS                                        *
***********************************************************************************************************

****************
*CHAPTER MODELS*
****************

ologit comcomax dcen fh mixed majplr age prz elf lnGDP05  y1-y16, robust
 outreg dcen fh mixed majplr age prz elf lnGDP05  using Book_Conflict1, replace se 3aster coefastr bdec(2) rdec(3) addstat(Log Pseudolikelihood,  e(ll)) adec(3)
*Note: Putting a dummy variable in this model for Latin America does not change the result for presidentialism.

*****************
*APPENDIX MODELS*
*****************

*SQUARED ELF TERM*
ologit comcomax dcen fh mixed majplr age prz elf sqelf lnGDP05 y1-y16, robust
 outreg dcen fh mixed majplr age prz elf lnGDP05 sqelf using Book_Appendix_Conflict1, replace se 3aster coefastr bdec(2) rdec(3) addstat(Log Pseudolikelihood,  e(ll)) adec(3) title(Anti-regime Rebellion: Alternative ELF and GDP Models (Base Models))

*BASE MODEL WITH SUBSTITUTIONS - PER CAPITA GDP INSTEAD OF TOTAL GDP*

ologit comcomax dcen fh mixed majplr age prz elf lnGDP05 lnGDPcap05 elf y1-y16, robust
 outreg dcen fh mixed majplr age prz elf lnGDP05 lnGDPcap05 elf using Book_Appendix_Conflict1, append replace se 3aster coefastr bdec(2) rdec(3) addstat(Log Pseudolikelihood,  e(ll)) adec (3) 

ologit comcomax dcen fh mixed majplr age prz lnGDPcap05 elf y1-y16, robust
 outreg dcen fh mixed majplr age prz lnGDPcap05 elf using Book_Appendix_Conflict1, append replace se 3aster coefastr bdec(2) rdec(3) addstat(Log Pseudolikelihood,  e(ll)) adec (3)

*BASE MODEL WITH SUBSTITUTIONS - ALTERNATIVE MEASURES OF ELECTIONS/ELECTORAL SYSTEM TYPE*

ologit comcomax dcen fh avdm age prz elf lnGDP05  y1-y16, robust
 outreg dcen fh avdm age prz elf lnGDP05  using Book_Appendix_Conflict1a, replace se 3aster coefastr bdec(2) rdec(3) addstat(Log Pseudolikelihood,  e(ll)) adec(3) title (Anti-regime Rebellion: Alternative Measures of Elections (Base Models))

ologit comcomax dcen fh mixed majplr elect prz elf lnGDP05  y1-y16, robust
 outreg dcen fh mixed majplr elect prz elf lnGDP05  using Book_Appendix_Conflict1a, append replace se 3aster coefastr bdec(2) rdec(3) addstat(Log Pseudolikelihood,  e(ll)) adec(3)

ologit comcomax dcen fh mixed majplr felect prz elf lnGDP05  y1-y16, robust
 outreg dcen fh mixed majplr felect prz elf lnGDP05  using Book_Appendix_Conflict1a, append replace se 3aster coefastr bdec(2) rdec(3) addstat(Log Pseudolikelihood,  e(ll)) adec(3)

ologit comcomax dcen fh mixed majplr felect2 prz elf lnGDP05  y1-y16, robust
 outreg dcen fh mixed majplr felect2 prz elf lnGDP05  using Book_Appendix_Conflict1a, replace append se 3aster coefastr bdec(2) rdec(3) addstat(Log Pseudolikelihood,  e(ll)) adec(3)



*********************************************************************************************************
* CONFLICT - DECENTRALIZATION AND REGIONAL PARTY VOTE MODELS                                           * 
*********************************************************************************************************

****************
*CHAPTER MODELS*
****************

ologit comcomax dcen furpNUMBER fh mixed majplr age prz elf lnGDP05 y1-y16, robust
  outreg dcen furpNUMBER fh mixed majplr age prz elf lnGDP05  using Book_Conflict1, append replace se 3aster coefastr bdec(2) rdec(3) addstat(Log Pseudolikelihood,  e(ll)) adec(3)

ologit comcomax dcen furpVOTE fh mixed majplr age prz elf lnGDP05 y1-y16, robust
  outreg dcen furpVOTE fh mixed majplr age prz elf lnGDP05 using Book_Conflict1, append replace se 3aster coefastr bdec(2) rdec(3) addstat(Log Pseudolikelihood,  e(ll)) adec(3)

ologit comcomax dcen furpSEAT fh mixed majplr age prz elf lnGDP05 y1-y16, robust
  outreg dcen furpSEAT fh mixed majplr age prz elf lnGDP05 using Book_Conflict1, append replace se 3aster coefastr bdec(2) rdec(3) addstat(Log Pseudolikelihood,  e(ll)) adec(3)


*****************
*APPENDIX MODELS*
*****************

*ALTERNATIVE MEASURES OF REGIONAL PARTIES - DENATIONALIZATION*
ologit comcomax dcen denat fh mixed majplr age prz elf lnGDP05 y1-y16, robust
 outreg dcen denat fh mixed majplr age prz elf lnGDP05 using Book_Appendix_Conflict1b, replace se 3aster coefastr bdec(2) rdec(3) addstat(Log Pseudolikelihood,  e(ll)) adec(3) title (Conflict: Alternative Measures/Models of Regional Parties (Base Models)) 

*CONFLICTS TABLE MODELS OF NUMBER AND VOTES RESTRICTED TO SEAT POPULATION* 
ologit comcomax dcen furpNUMBER fh mixed majplr age prz elf lnGDP05 y1-y16 if furpSEAT != ., robust
 outreg dcen furpNUMBER fh mixed majplr age prz elf lnGDP05 using Book_Appendix_Conflict1b, append replace se 3aster coefastr bdec(2) rdec(3) addstat(Log Pseudolikelihood,  e(ll)) adec(3)

ologit comcomax dcen furpVOTE fh mixed majplr age prz elf lnGDP05 y1-y16 if furpSEAT != ., robust
 outreg dcen furpVOTE fh mixed majplr age prz elf lnGDP05 using Book_Appendix_Conflict1b, append replace se 3aster coefastr bdec(2) rdec(3) addstat(Log Pseudolikelihood,  e(ll)) adec(3)


*CONFLICT TABLE MODELS WITHOUT ELF*

ologit comcomax dcen furpVOTE fh mixed majplr age prz lnGDP05 y1-y16, robust
  outreg dcen furpVOTE fh mixed majplr age prz elf lnGDP05  using Book_Appendix_Conflict1d, replace se 3aster coefastr bdec(2) rdec(3) addstat(Log Pseudolikelihood,  e(ll)) adec(3) title (Conflict: Regional Party Vote Models with ELF)
 
ologit comcomax dcen furpNUMBER fh mixed majplr age prz lnGDP05 y1-y16, robust
  outreg dcen furpNUMBER fh mixed majplr age prz elf lnGDP05  using Book_Appendix_Conflict1d, append replace se 3aster coefastr bdec(2) rdec(3) addstat(Log Pseudolikelihood,  e(ll)) adec(3)

ologit comcomax dcen furpSEAT fh mixed majplr age prz lnGDP05 y1-y16, robust
  outreg dcen furpSEAT fh mixed majplr age prz elf lnGDP05  using Book_Appendix_Conflict1d, append replace se 3aster coefastr bdec(2) rdec(3) addstat(Log Pseudolikelihood,  e(ll)) adec(3)

*GEOGRAPHIC REGION MODELS*
clear 
use "D:\Book Analysis I\Brancati_PBDQA1long.gregions.dta"
ologit comcomax dcen gfurp fh mixed majplr age prz elf lnGDP05  y1-y16, robust
  outreg dcen gfurp fh mixed majplr age prz elf lnGDP05 using Book_Appendix_Conflict1e, replace se 3aster coefastr bdec(2) rdec(3) addstat(Log Pseudolikelihood,  e(ll)) adec(3) title (Conflict: Regional Party Vote Models with ELF)
ologit comcomax dcen gfurpVOTE fh mixed majplr age prz elf lnGDP05  y1-y16, robust
  outreg dcen gfurpVOTE fh mixed majplr age prz elf lnGDP05 using Book_Appendix_Conflict1e, replace se 3aster coefastr bdec(2) rdec(3) addstat(Log Pseudolikelihood,  e(ll)) adec(3) title (Conflict: Regional Party Vote Models with ELF)
ologit comcomax dcen gfurpSEAT fh mixed majplr age prz elf lnGDP05  y1-y16, robust
  outreg dcen gfurpSEAT fh mixed majplr age prz elf lnGDP05 using Book_Appendix_Conflict1e, replace se 3aster coefastr bdec(2) rdec(3) addstat(Log Pseudolikelihood,  e(ll)) adec(3) title (Conflict: Regional Party Vote Models with ELF)

***************************************************************************************************************
* ALTERNATIVE MEASURES OF DECENTRALIZATION                                                                    *
***************************************************************************************************************

******************
* CHAPTER MODELS *
******************

ologit comcomax dcenIndex furpVOTE fh mixed majplr age prz elf lnGDP05 y1-y16, robust
  outreg using Book_Conflict2, replace se 3aster coefastr bdec(2) rdec(3) addstat(Log Pseudolikelihood,  e(ll)) adec(3)
prvalue, x(dcenIndex=0 fh=1  mixed=0 majplr=0 prz=1) rest(mean)
prvalue, x(dcenIndex=3 fh=1  mixed=0 majplr=0 prz=1) rest(mean) 
prvalue, x(dcenIndex=5  fh=1  mixed=0 majplr=0 prz=1) rest(mean) 

ologit comcomax dcen EXPshare05 furpVOTE fh mixed majplr age prz elf lnGDP05 y1-y16 if REVgdp05!=., robust
   outreg using Book_Conflict2, append replace se 3aster coefastr bdec(2) rdec(3) addstat(Log Pseudolikelihood,  e(ll)) adec(3)

ologit comcomax dcen REVgdp05 furpVOTE fh mixed majplr age prz elf lnGDP05 y1-y16 if EXPshare05 !=., robust
 outreg using Book_Conflict2, replace append se 3aster coefastr bdec(2) rdec(3) addstat(Log Pseudolikelihood,  e(ll)) adec(3)


*******************
* APPENDIX MODELS *
*******************

*ADDITIONAL FISCAL DECENTRALIZATION MODELS*

ologit comcomax dcen EXPgdp05 furpVOTE fh mixed majplr age prz elf lnGDP05 y1-y16, robust 
    outreg dcen EXPgdp05 furpVOTE fh mixed majplr age prz elf lnGDP05 using Book_Appendix_Conflict2b, replace se 3aster coefastr bdec(2) rdec(3) addstat(Log Pseudolikelihood,  e(ll)) adec(3) title (Inter-communal  Conflict: Additional Fiscal Decentralization Models without Controls for Political Decentralization or Restricted to these Systems) 

ologit comcomax EXPshare05 furpVOTE fh mixed majplr age prz elf lnGDP05 y1-y16 if REVgdp05 !=., robust
   outreg EXPshare05 furpVOTE fh mixed majplr age prz elf lnGDP05 using Book_Appendix_Conflict2b, replace se 3aster coefastr bdec(2) rdec(3) addstat(Log Pseudolikelihood,  e(ll)) adec(3) 

ologit comcomax REVgdp05 furpVOTE fh mixed majplr age prz elf lnGDP05 y1-y16 if EXPshare05 !=., robust
   outreg REVgdp05 furpVOTE fh mixed majplr age prz elf lnGDP05 using Book_Appendix_Conflict2b, append replace se 3aster coefastr bdec(2) rdec(3) addstat(Log Pseudolikelihood,  e(ll)) adec(3)

ologit comcomax EXPshare05 furpVOTE fh mixed majplr age prz elf lnGDP05 y1-y16 if REVgdp05 !=. & dcen == 1, robust
   outreg EXPshare05 furpVOTE fh mixed majplr age prz elf lnGDP05 using Book_Appendix_Conflict2b, append replace se 3aster coefastr bdec(2) rdec(3) addstat(Log Pseudolikelihood,  e(ll)) adec(3)
*result not the same without the elf index*

ologit comcomax REVgdp05 furpVOTE fh mixed majplr age prz elf lnGDP05 y1-y16 if EXPshare05 !=. & dcen == 1, robust
   outreg REVgdp05 furpVOTE fh mixed majplr age prz elf lnGDP05 using Book_Appendix_Conflict2b, append replace se 3aster coefastr bdec(2) rdec(3) addstat(Log Pseudolikelihood,  e(ll)) adec(3)
*result the same without the elf index*

*ADDITIONAL FISCAL DECENTRALIZATION MODELS: VARIATION ON REGIONAL PARTY VOTE*
ologit comcomax dcen EXPshare05 furpNUMBER fh mixed majplr age prz elf lnGDP05 y1-y16, robust
   outreg dcen EXPshare05 furpNUMBER fh mixed majplr age prz elf lnGDP05 using Book_Appendix_Conflict2b2, replace se 3aster coefastr bdec(2) rdec(3) addstat(Log Pseudolikelihood,  e(ll)) adec(3) title (Conflict: Additional Fiscal Decentralization Models with Variations on Regional Party Strength) 

ologit comcomax dcen EXPshare05 furpSEAT fh mixed majplr age prz elf lnGDP05 y1-y16, robust
   outreg dcen EXPshare05 furpSEAT fh mixed majplr age prz elf lnGDP05 using Book_Appendix_Conflict2b2, append replace se 3aster coefastr bdec(2) rdec(3) addstat(Log Pseudolikelihood,  e(ll)) adec(3)

ologit comcomax dcen REVgdp05 furpNUMBER fh mixed majplr age prz elf lnGDP05 y1-y16, robust
 outreg dcen REVgdp05 furpNUMBER fh mixed majplr age prz elf lnGDP05 using Book_Appendix_Conflict2b2, append replace se 3aster coefastr bdec(2) rdec(3) addstat(Log Pseudolikelihood,  e(ll)) adec(3)

ologit comcomax dcen REVgdp05 furpSEAT fh mixed majplr age prz elf lnGDP05 y1-y16, robust
 outreg dcen REVgdp05 furpSEAT fh mixed majplr age prz elf lnGDP05  using Book_Appendix_Conflict2b2, append replace se 3aster coefastr bdec(2) rdec(3) addstat(Log Pseudolikelihood,  e(ll)) adec(3)


*CONFLICT TABLE MODELS RESTRICTED TO SAME POPULATION AS FISCAL DECENTRALIZATION MODEL*

ologit comcomax dcen fh mixed majplr age prz elf lnGDP05 y1-y16 if EXPshare05 != . & REVgdp05 != ., robust
   outreg dcen fh mixed majplr age prz elf lnGDP05 using Book_Appendix_Conflict2c, replace se 3aster coefastr bdec(2) rdec(3) addstat(Log Pseudolikelihood,  e(ll)) adec(3) title (Conflict Models Restricted to the Same Population as the Fiscal Decentralization Models)

ologit comcomax dcen furpNUMBER fh mixed majplr age prz elf lnGDP05 y1-y16 if EXPshare05 != . & REVgdp05 != ., robust
   outreg dcen furpNUMBER fh mixed majplr age prz elf lnGDP05  using Book_Appendix_Conflict2c, append replace se 3aster coefastr bdec(2) rdec(3) addstat(Log Pseudolikelihood,  e(ll)) adec(3)

ologit comcomax dcen furpVOTE fh mixed majplr age prz elf lnGDP05 y1-y16 if EXPshare05 != . & REVgdp05 != ., robust
   outreg dcen furpVOTE fh mixed majplr age prz elf lnGDP05 using Book_Appendix_Conflict2c, append replace se 3aster coefastr bdec(2) rdec(3) addstat(Log Pseudolikelihood,  e(ll)) adec(3)

ologit comcomax dcen furpSEAT fh mixed majplr age prz elf lnGDP05 y1-y16 if EXPshare05 != . & REVgdp05 != ., robust
   outreg dcen furpSEAT fh mixed majplr age prz elf lnGDP05  using Book_Appendix_Conflict2c, append replace se 3aster coefastr bdec(2) rdec(3) addstat(Log Pseudolikelihood,  e(ll)) adec(3)

ologit comcomax dcenIndex furpVOTE fh mixed majplr age prz elf lnGDP05 y1-y16 if EXPshare05 != . & REVgdp05 != . , robust
   outreg dcenIndex furpVOTE fh mixed majplr age prz elf lnGDP05 using Book_Appendix_Conflict2c, append replace se 3aster coefastr bdec(2) rdec(3) addstat(Log Pseudolikelihood,  e(ll)) adec(3)


*************************************************************************************************************
* CONFLICT - DECENTRALIZATION INTERACTION MODELS                                                           *
*************************************************************************************************************

****************
*CHAPTER MODELS*
****************

gen dcenNUMBER = dcen*furpNUMBER 
ologit comcomax dcen furpNUMBER dcenNUMBER fh mixed majplr age prz elf lnGDP05 y1-y16, robust
outreg using Book_Conflict3, replace se 3aster coefastr bdec(2) rdec(3) addstat(Log Pseudolikelihood,  e(ll)) adec(3)
test dcen furpNUMBER dcenNUMBER
 
gen dcenVOTE = dcen*furpVOTE 
ologit comcomax dcen furpVOTE dcenVOTE fh mixed majplr age prz elf lnGDP05 y1-y16, robust
outreg using Book_Conflict3, append replace se 3aster coefastr bdec(2) rdec(3) addstat(Log Pseudolikelihood,  e(ll)) adec(3)
test dcen furpVOTE dcenVOTE


gen dcenSEAT = dcen*furpSEAT 
ologit comcomax dcen furpSEAT dcenSEAT fh mixed majplr age prz elf lnGDP05 y1-y16, robust
outreg using Book_Conflict3, append replace se 3aster coefastr bdec(2) rdec(3) addstat(Log Pseudolikelihood,  e(ll)) adec(3)
test dcen furpSEAT dcenSEAT


*******************
* APPENDIX MODELS *
*******************

*INTERACTION MODELS CANNOT BE RESTRICTED TO SAME POPULATION AS FISCAL DECENTRALIZATION MODEL - TOO MUCH COLLINEARITY*

*INTERACTION MODELS WITH ALTERNATIVE MEASURES OF DECENTRALIZATION/REGIONAL PARTIES*

gen furpvoteEXPshare05 = furpVOTE*EXPshare05
ologit comcomax dcen furpVOTE furpvoteEXPshare05 EXPshare05 fh mixed majplr age prz elf lnGDP05 y1-y16, robust
outreg dcen furpVOTE furpvoteEXPshare05 EXPshare05 fh mixed majplr age prz elf lnGDP05 using Book_Appendix_Conflict3a, replace se 3aster coefastr bdec(2) rdec(3) addstat(Log Pseudolikelihood,  e(ll)) adec(3) title(Alternative Interaction Models)
test dcen EXPshare05 furpvoteEXPshare05

gen dcenIVote = dcenIndex*furpVOTE 
ologit comcomax dcenIndex furpVOTE dcenIVote fh mixed majplr age prz elf lnGDP05 y1-y16, robust
outreg dcenIndex furpVOTE dcenIVote fh mixed majplr age prz elf lnGDP05  using Book_Appendix_Conflict3a, append replace se 3aster coefastr bdec(2) rdec(3) addstat(Log Pseudolikelihood,  e(ll)) adec(3)
prvalue, x(dcenIndex=1 furpVOTE = 5 dcenIVote=5 fh=1 mixed=0 majplr=0 prz=1) rest(mean)
prvalue, x(dcenIndex=1 furpVOTE = 15 dcenIVote=5 fh=1 mixed=0 majplr=0 prz=1) rest(mean)
prvalue, x(dcenIndex=4 furpVOTE = 5 dcenIVote=5 fh=1 mixed=0 majplr=0 prz=1) rest(mean)
prvalue, x(dcenIndex=4 furpVOTE = 15 dcenIVote=5 fh=1 mixed=0 majplr=0 prz=1) rest(mean)

gen dcenISeat = dcenIndex*furpSEAT 
ologit comcomax dcenIndex furpSEAT dcenISeat fh mixed majplr age prz elf lnGDP05 y1-y16, robust
test dcenIndex furpSEAT dcenISeat
prvalue, x(dcenIndex=1 furpSEAT = 5 dcenISeat=5 fh=1 mixed=0 majplr=0 prz=1) rest(mean) save
prvalue, x(dcenIndex=1 furpSEAT = 15 dcenISeat=5 fh=1 mixed=0 majplr=0 prz=1) rest(mean) diff
prvalue, x(dcenIndex=4 furpSEAT = 5 dcenISeat=5 fh=1 mixed=0 majplr=0 prz=1) rest(mean)
prvalue, x(dcenIndex=4 furpSEAT = 15 dcenISeat=5 fh=1 mixed=0 majplr=0 prz=1) rest(mean)

test dcenIndex furpVOTE dcenIVote

gen dcenDENAT = dcen*denat
ologit comcomax dcen dcenDENAT denat fh mixed majplr age prz elf lnGDP05 y1-y16, robust
outreg dcen dcenDENAT denat fh mixed majplr age prz elf lnGDP05  using Book_Appendix_Conflict3a, append replace se 3aster coefastr bdec(2) rdec(3) addstat(Log Pseudolikelihood,  e(ll)) adec(3)
test dcen denat dcenDENAT

 

*##############################################################################################*
*                     #################################################                        *
*                     # INSTRUMENTAL VARIABLE  REGRESSION             #                        *
*                     #################################################                        *
*##############################################################################################*

gen Xlaw = 1 if cnty == "Indonesia" | cnty == "Mexico" | cnty == "Turkey"
recode Xlaw . = 0 

***********************************************
*Correlations between Instruments and Outcomes*
***********************************************
pwcorr UKcolony rebelmean
pwcorr UKcolony comcomean
pwcorr surface rebelmean
pwcorr surface comcomean
pwcorr noncontig rebelmean
pwcorr noncontig comcomean
pwcorr Xlaw rebelmean
pwcorr Xlaw comcomean
pwcorr przcon rebelmean
pwcorr przcon comcomean
pwcorr prznoncon rebelmean
pwcorr prznoncon comcomean

**************
* REBEL/VOTE *
**************

*The fixed effects for years have been omitted because they are dropped differently from the IVREG and REG models, which is problematic for the Hausman test.*

*((Chapter Models))
ivreg2 rebelmean furpVOTE fh age mixed majplr prz elf lnGDP05 (dcen =  UKcolony surface), first robust
outreg using Book_IVa, replace se 3aster coefastr bdec(2) rdec(3) addstat(Centered R-squared, e(r2u))
estimates store ivreg
reg rebelmean dcen furpVOTE fh age mixed majplr prz elf lnGDP05, robust
hausman ivreg ., constant sigmamore

ivreg2 rebelmean furpVOTE fh age mixed majplr prz elf lnGDP05 (dcenIndex =  UKcolony surface), first 
ivendog

*((Alternative Models))*
*Does not pass Sargan*
ivreg2 rebelmean furpVOTE fh age mixed majplr prz elf lnGDP05 (dcen =  surface noncontig UKcolony), first robust
ivendog
ivreg2 rebelmean furpVOTE fh age mixed majplr prz elf lnGDP05  (dcen=noncontig surface), first
ivendog
ivreg2 rebelmean furpVOTE fh age mixed majplr prz elf lnGDP05 (dcen =  UKcolony noncontig), first
ivendog

*((Chapter Models))*
ivreg2 rebelmean dcen fh age mixed majplr prz elf lnGDP05 (furpVOTE = Xlaw), first robust
outreg using Book_IVa, append replace se 3aster coefastr bdec(2) rdec(3) addstat(Centered R-squared, e(r2u))
estimates store ivreg
reg rebelmean dcen furpVOTE fh age mixed majplr prz elf lnGDP05, robust
hausman ivreg ., constant sigmamore 

ivreg2 rebelmean dcen fh age mixed majplr prz elf lnGDP05 (furpVOTE = Xlaw), first 
ivendog
ivreg2 rebelmean dcen fh age mixed majplr prz elf lnGDP05 (furpSEAT = Xlaw)
ivendog
ivreg2 rebelmean dcen fh age mixed majplr prz elf lnGDP05 (furpNUMBER = Xlaw)
ivendog

*((Alternative Models))*
*Passes Sargan*
ivreg2 rebelmean dcen fh age mixed majplr prz elf lnGDP05 (furpVOTE = tnre Xlaw), first robust
estimates store ivreg
reg rebelmean dcen furpVOTE fh age mixed majplr prz elf lnGDP05, robust
hausman ivreg ., constant sigmamore 
ivreg2 rebelmean dcen fh age mixed majplr prz elf lnGDP05 (furpVOTE = tnre Xlaw), first
ivendog

*Does not pass Sargan*
ivreg2 rebelmean dcen fh age mixed majplr elf lnGDP05 (furpVOTE = tnre Xlaw przcon przncon), first robust
ivendog
ivreg2 rebelmean dcen fh age mixed majplr elf lnGDP05 (furpVOTE = Xlaw przcon przncon), first robust
ivendog
ivreg2 rebelmean dcen fh age mixed majplr elf lnGDP05 (furpVOTE =  przcon przncon)
ivendog

*****************
* CONFLICT/VOTE *
*****************

*((Chapter Models))*
ivreg2 comcomean furpVOTE fh age mixed majplr prz elf lnGDP05 (dcen=noncontig UKcolony), first robust 
outreg using Book_IVa, append replace se 3aster coefastr bdec(2) rdec(3) addstat(Centered R-squared, e(r2u))
estimates store ivreg
reg comcomean dcen furpVOTE fh age mixed majplr prz elf lnGDP05, robust 
hausman ivreg ., constant sigmamore 

ivreg2 comcomean furpVOTE fh age mixed majplr prz elf lnGDP05 (dcenIndex=noncontig UKcolony), first  
ivendog

*((Alternative Models))*
*Passes Sargan Tests*
ivreg2 comcomean furpVOTE fh age mixed majplr prz elf lnGDP05 (dcen=surface noncontig), first robust
ivendog
*Does not pass Sargan*
ivreg2 comcomean furpVOTE fh age mixed majplr prz elf lnGDP05  (dcen=surface noncontig UKcolony), first robust 
ivendog
ivreg2 comcomean furpVOTE fh age mixed majplr prz elf lnGDP05 (dcen=surface UKcolony), first
ivendog


*((Chapter Models))*
ivreg2 comcomean dcen fh age mixed majplr elf lnGDP05 (furpVOTE = przcon przncon Xlaw), first robust
outreg using Book_IVa, append replace se 3aster coefastr bdec(2) rdec(3) addstat(Centered R-squared, e(r2u))
estimates store ivreg
reg comcomean dcen furpVOTE fh age mixed majplr elf majplr lnGDP05, robust
hausman ivreg ., constant sigmamore 
ivreg2 comcomean dcen fh age mixed majplr elf lnGDP05 (furpVOTE = przcon przncon Xlaw), first
ivendog

*ivreg2 comcomean dcen fh age mixed majplr elf lnGDP05 (furpSEAT = przcon przncon Xlaw), first robust
*ivreg2 comcomean dcen fh age mixed majplr elf lnGDP05 (furpNUMBER = przcon przncon Xlaw), first robust

*((Alternative Models))*
*Also Passes Sargan Tests*
        

ivreg2 comcomean dcen fh age mixed majplr prz elf lnGDP05 (furpVOTE = tnre Xlaw), first robust
ivendog
*Does Not Pass Sargan Tests*
ivreg2 comcomean dcen fh age mixed majplr prz elf lnGDP05 (furpVOTE = Xlaw), first robust
ivendog
ivreg2 comcomean dcen fh age mixed majplr elf lnGDP05 (furpVOTE =  Xlaw przcon przncon)
ivendog

