 
######################################################*
* QUANTIATIVE ANALYSIS II, PEACE BY DESIGN (BRANCATI)  *
*######################################################*

********************************************************************************
*                         DEFINITION OF VARIABLES					 *
********************************************************************************
*  dcen = dichotomous measure of decentralization				       *
*  dcenIndex = index of decentralization			                         *
*  furpVOTE = regional party vote (% of total vote)                            *
*  furpSEAT = regional party vote (% of total seats)                           *
*  furpNUMBER = regional parties (% of all parties)                            *
*    regions are defined as adminstrative divisions in this file.	             *
*  EXPshare05 = subnational expenditure (% of total expenditure)               *
*  EXPgdp05 = subnational expenditure (% of gdp)           			       *
*  REVgdp05 = subnational expenditure (% of gdp)                               *
*  mixed = mixed electoral system							       *
*  majplr = majority and plurality systems				             *
*  age = age of democracy				                               *
*  elect = election year                                                       *
*  felect = election year of first democratic elections                        *
*  felect2 = felect + 3 elections after periods where polity 5 fell below 5    *
*  prz = presidentialism								       *	
*  przcon = concurrent presidential and legislative elections		       *
*  przncon = nonconcurrent presidential and legislative elections	             *
*  rbase = % of pop (all groups over 1%) that has a regional base.           	 *
*  elf = ethnolinguistic fractionalization (elf) index.	 		       *
*  noncontig = country whose territory is noncontiguous			       *
*  UKcolony = former colony of the United Kingdom                              *
*  popWDI = population 									       *
********************************************************************************

***********************************************************************************************
*Coding Notes: 
*(1) Lithuania's electoral system is coded as mixed in QAI (dv = conflict/rebellion)	    *
*    because the electoral system is mixed overall. It is coded as majplr in QA2              *
*    because the regional party strength data is based on the single-member districts         *
*    only, and I am trying to test the effect of this aspect of the electoral system          *
*    on regional party strength.                                                              *
*(2) The following countries/legislatures are marked as majlpr [even though dm >1 because they*
*    are elected under majority or plurality rule (i.e., block voting): Bermuda (lower house),* 
*    Mauritius (lower house), Spain (Senate), Poland (Senate)                                 *
*(3) Mexico and Lithuania have mixed systems, but avdm = 1 since the regional party strength  *
*    data is based on the SMDs only. In QAI, avdm includes all districts (see 1 above). For   *
*    Mexico, it is missing since I do not know the dm for all Mexico's districts. DM does     *
*    include generally supplementary seats not distributed at the district level.             *
*(4) Population data for CSFR based on 1990 census. The remainder is based on World Bank.     *
*(5) Bermuda ELF based on estimates from CIA Factbook. The remainder are Roeder               *
***********************************************************************************************

*##############################################################################################*
*                     #################################################                        *
*                     #  NATIONAL ELECTIONS - NATIONAL LEVEL RESULTS  #                        *
*                     #################################################                        *
*##############################################################################################*

use "D:\Book Analysis II\QAIIa.Jan08.dta", clear

**********************
*DEMOGRAPHIC MODELS  *
**********************

**((((CHAPTER MODELS))))**
reg furpVOTE elf rbase forties fifties sixties seventies eighties nineties naughts, robust 
 outreg elf rbase using Book_QAIIaT1, replace se 3aster coefastr bdec(2) title (Table 7.1 Base Models) nonotes addnote(Decade-fixed effects not shown. Standard errors in parentheses.  *p=0.10, **p=0.05, ***p=0.01.)

**((((APPENDIX MODELS))))**
gen sqelf = elf*elf
reg furpVOTE elf sqelf rbase forties fifties sixties seventies eighties nineties naughts, robust 
   outreg elf sqelf rbase using Book_Appendix_QAIIaT1, replace se 3aster coefastr bdec(2) title (Base Models)

reg furpNUMBER elf rbase forties fifties sixties seventies eighties nineties naughts, robust 
  outreg elf rbase using Book_Appendix_QAIIaT1, replace se 3aster coefastr bdec(2) title (Base Models)

reg furpSEAT elf rbase forties fifties sixties seventies eighties nineties naughts, robust
   outreg elf rbase using Book_Appendix_QAIIaT1, append replace se 3aster coefastr bdec(2) title (Base Models)

************************************
*DECENTRALIZATION WITH DEMOGRAPHICS*
************************************

**((((CHAPTER MODELS))))**
reg furpVOTE dcen elf rbase forties fifties sixties seventies eighties nineties naughts, robust
  outreg dcen elf rbase using Book_QAIIaT1, append replace se 3aster coefastr bdec(2) title (Table 7.1 Base Models)

*Interaction between Regional Base and Electoral System*
gen rbase_majplr= majplr*rbase
 label variable rbase_majplr "Regional Base*Majority/Plurality Systems"
gen rbase_mixed=mixed*rbase
 label variable rbase_mixed "Regional Base*Mixed Systems"

reg furpVOTE dcen mixed majplr rbase rbase_mixed rbase_majplr forties fifties sixties seventies eighties nineties naughts, robust
  outreg dcen mixed majplr rbase rbase_mixed rbase_majplr using Book_QAIIaT1, append replace se 3aster coefastr bdec(2) title (Table 7.1 Base Models)
test rbase rbase_mixed
test rbase rbase_majplr 
test rbase rbase_mixed rbase_majplr
 *reg furpNUMBER dcen mixed majplr rbase rbase_mixed rbase_majplr przcon prznoncon age tnre Xlaw forties fifties sixties seventies eighties nineties naughts, robust
 *reg furpVOTE dcen mixed majplr rbase rbase_mixed rbase_majplr przcon prznoncon age tnre Xlaw forties fifties sixties seventies eighties nineties naughts, robust
 *reg furpSEAT dcen mixed majplr rbase rbase_mixed rbase_majplr przcon prznoncon age tnre Xlaw forties fifties sixties seventies eighties nineties naughts, robust
 *reg denat dcen mixed majplr rbase rbase_mixed rbase_majplr przcon prznoncon age tnre Xlaw forties fifties sixties seventies eighties nineties naughts, robust

**((((APPENDIX MODELS))))**
reg furpNUMBER dcen elf rbase forties fifties sixties seventies eighties nineties naughts, robust
  outreg using Book_Appendix_QAIIaT1, append replace se 3aster coefastr bdec(2) title (Base Models)

reg furpSEAT dcen elf rbase forties fifties sixties seventies eighties nineties naughts, robust
  outreg using Book_Appendix_QAIIaT1, append replace se 3aster coefastr bdec(2) title (Base Models)


***********************************************************************************
*DECENTRALIZATION, DEMOGRAPHIC AND POLITICAL INSTITUTIONS / DROP ELF (FULL MODELS)*
***********************************************************************************

**((((CHAPTER MODELS))))**
reg furpNUMBER dcen rbase przcon prznoncon mixed majplr age tnre Xlaw forties fifties sixties seventies eighties nineties naughts, robust
   outreg dcen rbase przcon prznoncon mixed majplr age tnre Xlaw using Book_QAIIaT2, replace se 3aster coefastr bdec(2) title (Table 7.2 Full Model) nonotes addnote(Decade-fixed effects not shown. Standard errors in parentheses.  *p=0.10, **p=0.05, ***p=0.01.)
   test przcon prznoncon
*reg furpNUMBER dcen rbase przcon prznoncon mixed majplr age tnre Xlaw forties fifties sixties seventies eighties nineties naughts if furpSEAT !=. , robust

reg furpVOTE dcen rbase przcon prznoncon  mixed majplr age tnre Xlaw forties fifties sixties seventies eighties nineties naughts, robust
    outreg dcen rbase przcon prznoncon mixed majplr age tnre Xlaw  using Book_QAIIaT2, append replace se 3aster coefastr bdec(2) title (Table 7.2 Full Model)
    test przcon prznoncon
*reg furpVOTE dcen rbase przcon prznoncon mixed majplr age tnre Xlaw forties fifties sixties seventies eighties nineties naughts if furpSEAT !=. , robust

*No Xlaw*
*reg furpVOTE mixed majplr rbase rbase_mixed rbase_majplr age tnre forties fifties sixties seventies eighties nineties naughts, robust
  *test rbase rbase_mixed
  *test rbase rbase_majplr 
  *test rbase rbase_mixed rbase_majplr

reg furpSEAT dcen rbase przcon prznoncon mixed majplr age tnre Xlaw forties fifties sixties seventies eighties nineties naughts, robust
  outreg dcen rbase przcon prznoncon mixed majplr age tnre Xlaw  using Book_QAIIaT2, append replace se 3aster coefastr bdec(2) title (Table 7.2 Full Model)
  test przcon prznoncon

reg denat dcen rbase przcon prznoncon mixed majplr age tnre Xlaw forties fifties sixties seventies eighties nineties naughts, robust
  outreg dcen rbase przcon prznoncon mixed majplr age tnre Xlaw using Book_QAIIaT2, append replace se 3aster coefastr bdec(2) title (Table 7.2 Full Model)
   test przcon prznoncon

********************************************************************************************
*DECENTRALIZATION, DEMOGRAPHIC AND (ALTERNATIVE MEASURES OF) POLITICAL INSTITUTIONAL MODELS*
********************************************************************************************

**((((APPENDIX MODELS))))**

*With ELF*
reg furpNUMBER dcen rbase przcon prznoncon mixed majplr age tnre Xlaw elf forties fifties sixties seventies eighties nineties naughts, robust
   outreg dcen rbase przcon prznoncon mixed majplr age tnre Xlaw using Book_QAIIaT2b, replace se 3aster coefastr bdec(2) title (Table 7.2 Full Model) nonotes addnote(Decade-fixed effects not shown. Standard errors in parentheses.  *p=0.10, **p=0.05, ***p=0.01.)
reg furpVOTE dcen rbase przcon prznoncon  mixed majplr age tnre Xlaw elf forties fifties sixties seventies eighties nineties naughts, robust
   outreg dcen rbase przcon prznoncon mixed majplr age tnre Xlaw using Book_QAIIaT2b, append replace se 3aster coefastr bdec(2) title (Table 7.2 Full Model) nonotes addnote(Decade-fixed effects not shown. Standard errors in parentheses.  *p=0.10, **p=0.05, ***p=0.01.)
reg furpSEAT dcen rbase przcon prznoncon mixed majplr age tnre Xlaw elf forties fifties sixties seventies eighties nineties naughts, robust
   outreg dcen rbase przcon prznoncon mixed majplr age tnre Xlaw using Book_QAIIaT2b, append replace se 3aster coefastr bdec(2) title (Table 7.2 Full Model) nonotes addnote(Decade-fixed effects not shown. Standard errors in parentheses.  *p=0.10, **p=0.05, ***p=0.01.)
reg denat dcen rbase przcon prznoncon mixed majplr age tnre Xlaw elf forties fifties sixties seventies eighties nineties naughts, robust
   outreg dcen rbase przcon prznoncon mixed majplr age tnre Xlaw using Book_QAIIaT2b, append replace se 3aster coefastr bdec(2) title (Table 7.2 Full Model) nonotes addnote(Decade-fixed effects not shown. Standard errors in parentheses.  *p=0.10, **p=0.05, ***p=0.01.)

*Presidentialism (ignoring timing)*
 reg furpVOTE dcen rbase prz mixed majplr age tnre Xlaw forties fifties sixties seventies eighties nineties naughts, robust
    outreg using Book_Appendix_QAIIaT2, append replace se 3aster coefastr bdec(2) title (Base Models-Alternative Political Institution Variables)
 reg furpNUMBER dcen rbase prz mixed majplr age tnre Xlaw forties fifties sixties seventies eighties nineties naughts, robust
 reg furpSEAT dcen rbase prz mixed majplr age tnre Xlaw forties fifties sixties seventies eighties nineties naughts, robust
 reg denat dcen rbase prz mixed majplr age tnre Xlaw forties fifties sixties seventies eighties nineties naughts, robust
 
*Prez only without BiH*
 reg furpVOTE dcen rbase prz mixed majplr age tnre Xlaw forties fifties sixties seventies eighties nineties naughts if cnty != "Bosnia-Herzegovina", robust
 reg furpNUMBER dcen rbase prz mixed majplr age tnre Xlaw forties fifties sixties seventies eighties nineties naughts if cnty != "Bosnia-Herzegovina", robust
 reg furpSEAT dcen rbase prz mixed majplr age tnre Xlaw forties fifties sixties seventies eighties nineties naughts if cnty != "Bosnia-Herzegovina", robust
 reg denat dcen rbase prz mixed majplr age tnre Xlaw forties fifties sixties seventies eighties nineties naughts if cnty != "Bosnia-Herzegovina", robust

*Presidentialism without Iceland and Ireland*
reg furpNUMBER dcen rbase prz mixed majplr age tnre Xlaw forties fifties sixties seventies eighties nineties naughts if cnty !="Ireland" & cnty != "Iceland", robust
reg furpVOTE dcen rbase prz mixed majplr age tnre Xlaw forties fifties sixties seventies eighties nineties naughts if cnty !="Ireland" & cnty != "Iceland", robust
reg furpSEAT dcen rbase prz mixed majplr age tnre Xlaw forties fifties sixties seventies eighties nineties naughts if cnty !="Ireland" & cnty != "Iceland", robust
reg denat dcen rbase prz mixed majplr age tnre Xlaw forties fifties sixties seventies eighties nineties naughts if cnty !="Ireland" & cnty != "Iceland", robust

*Concurrency without Iceland and Ireland*
reg furpNUMBER dcen rbase przcon prznoncon mixed majplr age tnre Xlaw forties fifties sixties seventies eighties nineties naughts if cnty !="Ireland" & cnty != "Iceland", robust
test przcon prznoncon
reg furpVOTE dcen rbase przcon prznoncon mixed majplr age tnre Xlaw forties fifties sixties seventies eighties nineties naughts if cnty !="Ireland" & cnty != "Iceland", robust
test przcon prznoncon
reg furpSEAT dcen rbase przcon prznoncon mixed majplr age tnre Xlaw forties fifties sixties seventies eighties nineties naughts if cnty !="Ireland" & cnty != "Iceland", robust
test przcon prznoncon
reg denat dcen rbase przcon prznoncon mixed majplr age tnre Xlaw forties fifties sixties seventies eighties nineties naughts if cnty !="Ireland" & cnty != "Iceland", robust
test przcon prznoncon

*Concurrency without BiH*
reg furpVOTE dcen rbase prznoncon przcon mixed majplr age tnre Xlaw forties fifties sixties seventies eighties nineties naughts if cnty != "Bosnia-Herzegovina", robust
    outreg using Book_Appendix_QAIIaT2, append replace se 3aster coefastr bdec(2) title (Base Models-Alternative Political Institution Variables)
 test prznoncon przcon
reg furpNUMBER dcen rbase prznoncon przcon mixed majplr age tnre Xlaw forties fifties sixties seventies eighties nineties naughts if cnty != "Bosnia-Herzegovina", robust
 test prznoncon przcon
reg furpSEAT dcen rbase prznoncon przcon mixed majplr age tnre Xlaw forties fifties sixties seventies eighties nineties naughts if cnty != "Bosnia-Herzegovina", robust
 test prznoncon przcon
reg denat dcen rbase prznoncon przcon mixed majplr age tnre Xlaw forties fifties sixties seventies eighties nineties naughts if cnty != "Bosnia-Herzegovina", robust
 test prznoncon przcon


*Average DM*
reg furpVOTE dcen rbase prznoncon przcon avdm age tnre Xlaw forties fifties sixties seventies eighties nineties naughts, robust
    outreg using Book_Appendix_QAIIaT2, replace se 3aster coefastr bdec(2) title (Base Models-Alternative Political Institution Variables)
reg furpNUMBER dcen rbase prznoncon przcon avdm age tnre Xlaw forties fifties sixties seventies eighties nineties naughts, robust
reg furpSEAT dcen rbase prznoncon przcon avdm age tnre Xlaw forties fifties sixties seventies eighties nineties naughts, robust

  gen rbase_avdm=avdm*rbase
  reg furpNUMBER dcen avdm rbase rbase_avdm przcon prznoncon age tnre Xlaw forties fifties sixties seventies eighties nineties naughts, robust
  test avdm rbase rbase_avdm
  reg furpVOTE dcen avdm rbase rbase_avdm przcon prznoncon age tnre Xlaw forties fifties sixties seventies eighties nineties naughts, robust
  test avdm rbase rbase_avdm
  reg furpSEAT dcen avdm rbase rbase_avdm przcon prznoncon age tnre Xlaw forties fifties sixties seventies eighties nineties naughts, robust
  test avdm rbase rbase_avdm
  reg denat dcen avdm rbase rbase_avdm przcon prznoncon age tnre Xlaw forties fifties sixties seventies eighties nineties naughts, robust
  test avdm rbase rbase_avdm


*Felect*
 reg furpNUMBER dcen rbase prznoncon przcon mixed majplr felect tnre Xlaw forties fifties sixties seventies eighties nineties naughts, robust
 reg furpVOTE dcen rbase prznoncon przcon mixed majplr felect tnre Xlaw forties fifties sixties seventies eighties nineties naughts, robust
    outreg using Book_Appendix_QAIIaT2, append replace se 3aster coefastr bdec(2) title (Base Models-Alternative Political Institution Variables)
 reg furpSEAT dcen rbase prznoncon przcon mixed majplr felect tnre Xlaw forties fifties sixties seventies eighties nineties naughts, robust



**********************************************************************
*ALTERNATIVE MEASURES OF REGIONAL PARTIES BASED ON GEOGRAPHIC REGIONS*
**********************************************************************

use "D:\Book Analysis II\QAIIa.Jan08.gregions.dta" 
reg gfurp dcen prznoncon przcon mixed majplr age tnre Xlaw forties fifties sixties seventies eighties nineties naughts, robust
reg gfurp dcenIndex prznoncon przcon mixed majplr age tnre Xlaw forties fifties sixties seventies eighties nineties naughts, robust
reg gfurpVOTE dcen prznoncon przcon mixed majplr age tnre Xlaw forties fifties sixties seventies eighties nineties naughts, robust
reg gfurpVOTE dcenIndex prznoncon przcon mixed majplr age tnre Xlaw forties fifties sixties seventies eighties nineties naughts, robust
reg gfurpSEAT dcen prznoncon przcon mixed majplr age tnre Xlaw forties fifties sixties seventies eighties nineties naughts, robust
reg gfurpSEAT dcenIndex prznoncon przcon mixed majplr age tnre Xlaw forties fifties sixties seventies eighties nineties naughts, robust
clear

******************************************************************************
*ALTERNATIVE MEASURES OF DECENTRALIZATION (INDEX AND FISCAL DECENTRALIZATION)*
******************************************************************************
use "F:\Book Analysis II\QAIIaJan08.dta", replace 

**((((CHAPTER MODELS))))**

reg furpVOTE dcenIndex rbase prznoncon przcon mixed majplr age tnre Xlaw forties fifties sixties seventies eighties nineties naughts, robust
   outreg dcenIndex rbase prznoncon przcon mixed majplr age tnre Xlaw using Book_QAIIaT3, replace se 3aster coefastr bdec(2) title (Table 7.3 Alternative Measures of Decentralization) nonotes addnote(Decade-fixed effects not shown. Standard errors in parentheses.  *p=0.10, **p=0.05, ***p=0.01.)
 *reg furpNUMBER dcenIndex  rbase  prznoncon przcon mixed majplr age tnre Xlaw Xlaw forties fifties sixties seventies eighties nineties naughts, robust
 *reg furpSEAT dcenIndex rbase  prznoncon przcon mixed majplr age tnre Xlaw Xlaw forties fifties sixties seventies eighties nineties naughts, robust

reg furpVOTE dcen EXPshare05 rbase przcon prznoncon mixed majplr age tnre Xlaw forties fifties sixties seventies eighties nineties naughts if REVshare05 != ., robust
   outreg dcen EXPshare05  rbase przcon prznoncon mixed majplr age tnre Xlaw  using Book_QAIIaT3, append replace se 3aster coefastr bdec(2) title (Table 7.3 Alternative Measures of Decentralization)

reg furpVOTE dcen REVshare05 rbase przcon prznoncon mixed majplr age tnre Xlaw forties fifties sixties seventies eighties nineties naughts if EXPshare05 != ., robust
   outreg dcen REVshare05 rbase przcon prznoncon mixed majplr age tnre Xlaw  using Book_QAIIaT3, append replace se 3aster coefastr bdec(2) title (Table 7.3 Alternative Measures of Decentralization)

reg denat dcen EXPshare05 rbase przcon prznoncon mixed majplr age tnre Xlaw forties fifties sixties seventies eighties nineties naughts if REVshare05 != ., robust
   outreg dcen EXPshare05 rbase przcon prznoncon mixed majplr age tnre Xlaw  using Book_QAIIaT3, append replace se 3aster coefastr bdec(2) title (Table 7.3 Alternative Measures of Decentralization)

reg denat dcen REVshare05 rbase przcon prznoncon mixed majplr age tnre Xlaw forties fifties sixties seventies eighties nineties naughts if EXPshare05 != ., robust
   outreg dcen REVshare05 rbase przcon prznoncon mixed majplr age tnre Xlaw using Book_QAIIaT3 , append replace se 3aster coefastr bdec(2) title (Table 7.3 Alternative Measures of Decentralization)


**((((APPENDIX MODELS))))**
* ADDITIONAL FISCAL DECENTRALIZATION MEASURES*
reg denat dcen EXPgdp05 przcon prznoncon mixed majplr age tnre Xlaw forties fifties sixties seventies eighties nineties naughts if EXPshare05 != . & REVshare05 != . , robust
 outreg using Book_Appendix_QAIIaT4, replace se 3aster coefastr bdec(2) title  (Alternative Fiscal Decentralization Models)
reg furpVOTE dcen EXPgdp05 przcon prznoncon mixed majplr age tnre Xlaw forties fifties sixties seventies eighties nineties naughts if EXPshare05 != . & REVshare05 != . , robust
 outreg using Book_Appendix_QAIIaT4, append replace se 3aster coefastr bdec(2) title  (Alternative Fiscal Decentralization Models)
reg furpNUMBER dcen EXPgdp05 przcon prznoncon mixed majplr age tnre Xlaw forties fifties sixties seventies eighties nineties naughts if EXPshare05 != . & REVshare05 != . , robust
 outreg using Book_Appendix_QAIIaT4, append replace se 3aster coefastr bdec(2) title  (Alternative Fiscal Decentralization Models)
reg furpSEAT dcen EXPgdp05 przcon prznoncon mixed majplr age tnre Xlaw forties fifties sixties seventies eighties nineties naughts if EXPshare05 != . & REVshare05 != . , robust
 outreg using Book_Appendix_QAIIaT4, append replace se 3aster coefastr bdec(2) title  (Alternative Fiscal Decentralization Models)

**((((APPENDIX MODELS))))**
*DROP POLITICAL DECENTRALIZATION FROM FISCAL DECENTRALIZATION MODELS*

reg furpVOTE EXPshare05 przcon prznoncon mixed majplr felect tnre Xlaw forties fifties sixties seventies eighties nineties naughts if REVshare05 != ., robust
 outreg using Book_Appendix_QAIIaT4b, replace se 3aster coefastr bdec(2) title  (Alternative Fiscal Decentralization Models)

reg furpVOTE REVshare05 przcon prznoncon mixed majplr felect tnre Xlaw forties fifties sixties seventies eighties nineties naughts if EXPshare05 != ., robust 
  outreg using Book_Appendix_QAIIaT4b, append replace se 3aster coefastr bdec(2) title  (Alternative Fiscal Decentralization Models)

reg denat EXPshare05 przcon prznoncon mixed majplr felect tnre Xlaw forties fifties sixties seventies eighties nineties naughts if REVshare05 != ., robust
 outreg using Book_Appendix_QAIIaT4b, append replace se 3aster coefastr bdec(2) title  (Alternative Fiscal Decentralization Models)

reg denat REVshare05 przcon prznoncon mixed majplr felect tnre Xlaw forties fifties sixties seventies eighties nineties naughts if EXPshare05 != ., robust 
  outreg using Book_Appendix_QAIIaT4b, append replace se 3aster coefastr bdec(2) title  (Alternative Fiscal Decentralization Models)

**STRIP DOWN MODELS TO DECENTRALIZATION ONLY*
reg furpVOTE dcen EXPshare05 if REVshare05 != ., robust
reg furpVOTE dcen REVshare05 if EXPshare05 != ., robust
reg furpVOTE EXPshare05 if REVshare05 != ., robust
reg furpVOTE REVshare05 if EXPshare05 != ., robust
reg denat dcen EXPshare05 if REVshare05 != ., robust
reg denat dcen REVshare05 if EXPshare05 != ., robust
reg denat EXPshare05 if REVshare05 != ., robust
reg denat REVshare05 if EXPshare05 != ., robust

**((((APPENDIX MODELS))))**
*USE ALTERNATIVE MEASURE OF REGIONAL PARTIES IN THE FISCAL DECENTRALIZATION MODELS*
reg furpNUMBER dcen EXPshare05 przcon prznoncon mixed majplr age tnre Xlaw Xlaw forties fifties sixties seventies eighties nineties naughts if REVshare05 != ., robust
 outreg using Book_Appendix_QAIIaT4b, append replace se 3aster coefastr bdec(2) title  (Alternative Fiscal Decentralization Models)
reg furpSEAT dcen EXPshare05 przcon prznoncon mixed majplr age tnre Xlaw Xlaw forties fifties sixties seventies eighties nineties naughts if REVshare05 != ., robust
 outreg using Book_Appendix_QAIIaT4b, append replace se 3aster coefastr bdec(2) title  (Alternative Fiscal Decentralization Models)


*********************************
* CLUSTERED MODELS - MAIN MODELS*
*********************************

reg furpVOTE dcen rbase przcon prznoncon  mixed majplr age tnre Xlaw forties fifties sixties seventies eighties nineties naughts, cluster (cnty)
   outreg using Book_Appendix_QAIIaT5,  replace se 3aster coefastr bdec(2) title  (Main Models with Clustered SEs)
reg furpVOTE dcenIndex rbase prznoncon przcon mixed majplr age tnre Xlaw forties fifties sixties seventies eighties nineties naughts, cluster (cnty)
   outreg using Book_Appendix_QAIIaT5, append replace se 3aster coefastr bdec(2) title  (Main Models with Clustered SEs)
reg furpVOTE dcen EXPshare05  rbase przcon prznoncon mixed majplr age tnre Xlaw forties fifties sixties seventies eighties nineties naughts if REVshare05 != ., cluster (cnty)
   outreg using Book_Appendix_QAIIaT5, append replace se 3aster coefastr bdec(2) title  (Main Models with Clustered SEs)
reg furpVOTE REVshare05 przcon prznoncon mixed majplr age tnre Xlaw forties fifties sixties seventies eighties nineties naughts if EXPshare05 != ., cluster (cnty)
   outreg using Book_Appendix_QAIIaT5, append replace se 3aster coefastr bdec(2) title (Main Models with Clustered SEs)
reg denat dcen EXPshare05  rbase przcon prznoncon mixed majplr age tnre Xlaw forties fifties sixties seventies eighties nineties naughts if REVshare05 != ., cluster (cnty)
   outreg using Book_Appendix_QAIIaT5, append replace se 3aster coefastr bdec(2) title  (Main Models with Clustered SEs)
reg denat REVshare05 przcon prznoncon mixed majplr age tnre Xlaw forties fifties sixties seventies eighties nineties naughts if EXPshare05 != ., cluster (cnty)
   outreg using Book_Appendix_QAIIaT5, append replace se 3aster coefastr bdec(2) title (Main Models with Clustered SEs)

**************************************
*BETWEEN-EFFECTS MODELS - MAIN MODELS*
**************************************

collapse cnty

reg furpVOTE dcen rbase przcon prznoncon mixed majplr age tnre Xlaw 
   outreg using Book_Appendix_QAIIaT6,  replace se 3aster coefastr bdec(2) title (Between Effects - Main Models with Clustered SEs)
reg furpVOTE dcenIndex rbase prznoncon przcon mixed majplr age tnre Xlaw
   outreg using Book_Appendix_QAIIaT6, append replace se 3aster coefastr bdec(2) title (Between Effects - Main Models with Clustered SEs)
reg furpVOTE dcen EXPshare05  rbase przcon prznoncon mixed majplr age tnre Xlaw  if REVshare05 != .
   outreg using Book_Appendix_QAIIaT6, append replace se 3aster coefastr bdec(2) title (Between Effects - Main Models with Clustered SEs)
reg furpVOTE REVshare05 przcon prznoncon mixed majplr age tnre Xlaw if EXPshare05 != .
   outreg using Book_Appendix_QAIIaT6, append replace se 3aster coefastr bdec(2) title (Between Effects - Main Models with Clustered SEs)
reg denat dcen EXPshare05  rbase przcon prznoncon mixed majplr age tnre Xlaw  if REVshare05 != ., cluster (cnty)
   outreg using Book_Appendix_QAIIaT6, append replace se 3aster coefastr bdec(2) title (Between Effects - Main Models with Clustered SEs)
reg denat REVshare05 przcon prznoncon mixed majplr age tnre Xlaw forties if EXPshare05 != ., cluster (cnty)
   outreg using Book_Appendix_QAIIaT6, append replace se 3aster coefastr bdec(2) title (Between Effects - Main Models with Clustered SEs)

***************************************
*MAIN MODELS PLUS WORLD REGION DUMMIES*
***************************************

reg furpVOTE dcen rbase przcon prznoncon  mixed majplr age tnre Xlaw forties fifties sixties seventies eighties nineties naughts AsiaOceana Europe LatinCab Africa NAmerica, robust
   outreg using Book_Appendix_QAIIaT7,  replace se 3aster coefastr bdec(2) title  (Main Models with World Region Dummies)
reg furpVOTE dcenIndex rbase prznoncon przcon mixed majplr age tnre Xlaw forties fifties sixties seventies eighties nineties naughts AsiaOceana Europe LatinCab Africa NAmerica, robust
   outreg using Book_Appendix_QAIIaT7, append replace se 3aster coefastr bdec(2) 
reg furpVOTE dcen EXPshare05  rbase przcon prznoncon mixed majplr age tnre Xlaw forties fifties sixties seventies eighties nineties naughts AsiaOceana Europe LatinCab Africa NAmerica if REVshare05 != ., robust
   outreg using Book_Appendix_QAIIaT7, append replace se 3aster coefastr bdec(2) 
reg furpVOTE REVshare05 przcon prznoncon mixed majplr age tnre Xlaw forties fifties sixties seventies eighties nineties naughts AsiaOceana Europe LatinCab Africa NAmerica if EXPshare05 != ., robust
   outreg using Book_Appendix_QAIIaT7, append replace se 3aster coefastr bdec(2)
reg denat dcen EXPshare05  rbase przcon prznoncon mixed majplr age tnre Xlaw forties fifties sixties seventies eighties nineties naughts AsiaOceana Europe LatinCab Africa NAmerica if REVshare05 != ., robust
   outreg using Book_Appendix_QAIIaT7, append replace se 3aster coefastr bdec(2)
reg denat REVshare05 przcon prznoncon mixed majplr age tnre Xlaw forties fifties sixties seventies eighties nineties naughts AsiaOceana Europe LatinCab Africa NAmerica if EXPshare05 != ., robust
   outreg using Book_Appendix_QAIIaT7, append replace se 3aster coefastr bdec(2)

